@@ -3,17 +3,15 @@ import unicodedata
 
 from django.contrib.auth import password_validation
 from django.contrib.auth.hashers import check_password, is_password_usable, make_password
-from django.db.models import Model, DateTimeField
+from django.db.models import Model, DateTimeField, CharField
 from django.utils.crypto import salted_hmac
 from django.utils.translation import gettext_lazy as _
 
-from isc_common.fields.code_field import CodeField
-
 logger = logging.getLogger(__name__)
 
 
 class AbstractBaseUser(Model):
-    password = CodeField(_('пароль'))
+    password = CharField(_('пароль'), max_length=255)
     last_login = DateTimeField(_('последний вход'), blank=True, null=True)
 
     is_active = True
