@@ -29,7 +29,8 @@ class Command(BaseCommand):
             host=settings.WS_HOST,
             port=settings.WS_PORT,
             channel=f'common_{user.username}',
-            props=1 if cancel else 0
+            props=1 if cancel else 0,
+            user_id = user.id
         )
 
         if mode == 'open':
