@@ -673,11 +673,20 @@ class CommonManager(Manager):
                 return -1
         return -1
 
+    def check_data_for_multi_select(self, data):
+        for k, v in data.items():
+            if k == '0':
+                data = v
+            break
+        return data
+
     def updateFromRequest(self, request, removed=None, function=None, propsArr: List = None):
         if not isinstance(request, DSRequest):
             request = DSRequest(request=request)
         data = request.get_data()
 
+        data = self.check_data_for_multi_select(data=data)
+
         _data = data.copy()
 
         if self._dataIsArray(data):
@@ -706,15 +715,19 @@ class CommonManager(Manager):
             else:
                 props = self.get_prp(data=data, propsArr=propsArr)
                 cloned_data = self.clone_data(data)
+
                 if props > -1:
                     setAttr(cloned_data, 'props', props)
-                if request.get_id():
+
+                id = cloned_data.get('id')
+                if id is not None:
                     delAttr(cloned_data, 'id')
                     parent = cloned_data.get('parent')
                     if isinstance(parent, int):
                         delAttr(cloned_data, 'parent')
                         setAttr(cloned_data, 'parent_id', parent)
-                    super().update_or_create(id=request.get_id(), defaults=cloned_data)
+                    res = super().filter(id=id).update(**cloned_data)
+                    print(f'res: {res}')
                 else:
                     new_item = super().create(**cloned_data)
                     setAttr(_data, 'id', new_item.id)
