@@ -1,12 +1,12 @@
 def get_NoneStr(str):
-    if str == None:
+    if str is None:
         return ''
     else:
         return str
 
 
 def get_NullStr(str):
-    if str == None:
+    if str is None:
         return ''
     elif str == 'null':
         return ''
